homescreenpluginsrv/hspsmanager/src/hspsthemeserver.cpp
branchRCL_3
changeset 101 9e077f9a342c
parent 82 ace62b58f4b2
child 110 2c7f27287390
--- a/homescreenpluginsrv/hspsmanager/src/hspsthemeserver.cpp	Wed Jun 09 10:01:25 2010 +0300
+++ b/homescreenpluginsrv/hspsmanager/src/hspsthemeserver.cpp	Mon Jun 21 16:00:38 2010 +0300
@@ -2755,10 +2755,24 @@
         // Install widgets from \private\200159C0\install\ directories (ROM and UDA image)
         InstallWidgetsL();
 
         // Install widgets from \private\200159C0\imports\ directory (UDA image) C & E
         InstallUDAWidgetsL( KImportDirectoryC );
-        InstallUDAWidgetsL( KImportDirectoryE );
-        
+                
+        TInt drive = hspsServerUtil::GetEmmcDrivePath( iFsSession );
+        if ( drive != KErrNotFound )
+            {
+            TDriveUnit unit(drive);
+            HBufC* importDirectoryE = HBufC::NewLC( 
+                    KImportDirectory().Length() + unit.Name().Length() ); 
+            
+            importDirectoryE->Des().Append( unit.Name() );
+            importDirectoryE->Des().Append( KImportDirectory );
+            
+            InstallUDAWidgetsL( *importDirectoryE );
+            CleanupStack::PopAndDestroy( importDirectoryE );
+            }
+
         // Post RFS installations have been done, prevent re-installations at next startup
         // by reading firmware version and saving it to cenrep.
         GetFWVersion( fwVersion );
@@ -2755,10 +2755,24 @@
         InstallWidgetsL();
 
-        // Install widgets from \private\200159C0\imports\ directory (UDA image) C & E
+        // Install widgets from \private\200159C0\imports\ directory 
+        //from c (UDA image) and from emmc
         InstallUDAWidgetsL( KImportDirectoryC );